#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_EQUAL_WITH_EQUAL_NANS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_EQUAL_WITH_EQUAL_NANS_HPP_INCLUDED

#include <boost/simd/predicates/include/functions/scalar/is_equal_with_equal_nans.hpp>

#endif
